=========
Changelog
=========

Version 0.1.5
=============
- Bug today reference fixed
- Vacation now correctly added
- Font properties can be specified in setting file
- dayfist can be set to false

Version 0.1.3
=============

- Dynamic columns added
- First version of Gantt Project maker
- First bug fixes established
